@@ -27,7 +27,7 @@ use ODO::Ontology::RDFS::List::Iterator;
 use base qw/ODO/;
 
 use vars qw /$VERSION/;
-$VERSION = sprintf "%d.%02d", q$Revision: 1.61 $ =~ /: (\d+)\.(\d+)/;
+$VERSION = sprintf "%d.%02d", q$Revision: 1.62 $ =~ /: (\d+)\.(\d+)/;
 
 __PACKAGE__->mk_accessors(qw/graph/);
 
@@ -112,6 +112,40 @@ sub getClassIntersectionOf {
 	return $classIntersection;
 }
 
+sub getClassUnionOf {
+    my ( $self, $class ) = @_;
+    my $classURI = $class;
+    $classURI = $class->value()
+      if ( $class->isa( 'ODO::Node::Resource' ) );
+    my $owlUnionOf = $ODO::Ontology::OWL::Vocabulary::unionOf->value();
+    my $owlClass          = $ODO::Ontology::OWL::Vocabulary::Class->value();
+
+    # Find the owl:Class objects first
+    my $queryString  = "SELECT ?stmt WHERE (<$classURI>, <$owlUnionOf>, ?list)";
+    my $classResults = $self->graph()->query($queryString)->results();
+    my $classUnion = {
+                              classes      => [],
+                              restrictions => [],
+    };
+    if ( scalar( @{$classResults} ) ) {
+        my $list = ODO::RDFS::List->new( $classResults->[0]->object(), $self->graph() );
+        my $listIter = ODO::Ontology::RDFS::List::Iterator->new($list);
+        throw ODO::Exception::Runtime(
+                                   error => "Could not create iterator for ODO::RDFS::List" )
+          unless ( $listIter->isa( 'ODO::Ontology::RDFS::List::Iterator' ) );
+        my $iterElement;
+        while ( ( $iterElement = $listIter->next() ) ) {
+            if ( $iterElement->isa( 'ODO::Node::Blank' ) ) {
+                my $restriction = $self->getClassRestriction( $iterElement->value() );
+                push @{ $classUnion->{'restrictions'} }, $restriction;
+            } else {
+                push @{ $classUnion->{'classes'} }, $iterElement->value();
+            }
+        }
+    }
+    return $classUnion;
+}
+
 sub getClassRestriction {
 	my ( $self, $restrictionURI ) = @_;
 	my $restriction = { restrictionURI => $restrictionURI };
@@ -246,9 +280,15 @@ sub getClassRestriction {
         my $p = $ODO::Ontology::RDFS::Vocabulary::type->value();
         $queryString = "SELECT ?stmt WHERE (<$s>, <$p>, ?values)";
 	    $queryResults = $self->graph()->query($queryString)->results();
-	    if ( scalar( @{$queryResults} ) == 1 ) {
-	        $restriction->{'range'} = $queryResults->[0]->object()->value();
+	    foreach (@{$queryResults}) {
+	    	# ignore nodes typed as named individuals
+	    	next if $_->object()->value() eq 'http://www.w3.org/2002/07/owl#NamedIndividual';
+	    	$restriction->{'range'} = $_->object()->value();
+	    	last;
 	    }
+#	    if ( scalar( @{$queryResults} ) == 1 ) {
+#	        $restriction->{'range'} = $queryResults->[0]->object()->value();
+#	    }
         
     }
 	
@@ -390,9 +430,15 @@ sub getEquivalentClasses {
         my $p = $ODO::Ontology::RDFS::Vocabulary::type->value();
         $queryString = "SELECT ?stmt WHERE (<$s>, <$p>, ?values)";
         $queryResults = $self->graph()->query($queryString)->results();
-        if ( scalar( @{$queryResults} ) == 1 ) {
-            $restriction->{'range'} = $queryResults->[0]->object()->value();
+        foreach (@{$queryResults}) {
+        	#ignore nodes typed as named individuals
+            next if $_->object()->value() eq 'http://www.w3.org/2002/07/owl#NamedIndividual';
+            $restriction->{'range'} = $_->object()->value();
+            last;
         }
+#        if ( scalar( @{$queryResults} ) == 1 ) {
+#            $restriction->{'range'} = $queryResults->[0]->object()->value();
+#        }
     }
 	
 	return bless $restriction, 'ODO::Ontology::OWL::Lite::Fragments::EquivalentClass';
